# ext_m2_OrderShare  
  
This Magento 2 module adds the ability for customers to share their order on the following platforms:

 - Email
 - Twitter
 - Facebook
 - Google+
 - Linkedin
 - Pinterest
 - Mix
 - WhatsApp
 - Skype  
  
## Installation  
  
Use the package manager [composer](https://getcomposer.org/) to install the module.  
  
```bash  
composer require pinpoint/ordershare  
```  

## Configuration
To configure this module you need to go to `Admin > Stores > Configuration > Pinpoint > Order Social Share`. Inside here you will be able to manage if the module is enabled, which share buttons to show & add your own custom social media logos (`.png` recommended) to fit your theme if required. 

**NOTE:** These are to be placed (unless a further template is written) on the order success page.

## Usage  
### Display Social Share Buttons  
Adding share buttons to page via XML:  
```xml  
<block class="Pinpoint\OrderShare\Block\Success\Social" template="checkout/success/socials.phtml" after="-" />  
```
HTML required for share buttons:
```html
<div id="socials"></div>
```
Javascript to render share buttons:
```js
require(['jquery', 'socialButtons'], function($, jsSocials) {
    $(document).ready(function() {
        $('#socials').jsSocials({
            shares: [
                <?php if (isset($socials['jsSocials'])): ?>
                <?php foreach($socials['jsSocials'] as $share): ?> {
                    share: "<?= $share ?>",
                    showLabel: <?= $block->showLabel($share) ?>,
                    showCount: <?= $block->showCount($share) ?>,
                    <?php if ($image = $block->getCustomLogo($share)): ?>
                    logo: "<?= $image ?>"
                    <?php endif; ?>
                },
                <?php endforeach; ?>
                <?php endif; ?>
                <?php //NOTE: See here for more information: http://js-socials.com/docs/#renderer-function ?>
                <?php //adding custom share button for skype ?>
                <?php if ($socials['skype']): ?> {
                    renderer: function() {
                        var $result = $("<div>");

                        var script = document.createElement("script");
                        script.text = "(function(r, d, s) { r.loadSkypeWebSdkAsync = r.loadSkypeWebSdkAsync || function(p) { var js, sjs = d.getElementsByTagName(s)[0]; if (d.getElementById(p.id)) { return; } js = d.createElement(s); js.id = p.id; js.src = p.scriptToLoad; js.onload = p.callback; sjs.parentNode.insertBefore(js, sjs); }; var p = { scriptToLoad: 'https://swx.cdn.skype.com/shared/v/latest/skypewebsdk.js', id: 'skype_web_sdk' }; r.loadSkypeWebSdkAsync(p); })(window, document, 'script');";
                        $result.append(script);

                        $("<a>").addClass("skype-share")
                            .addClass("jssocials-share-link")
                            .attr("data-lang", "en-GB")
                            .attr('data-href', "<?= $block->getBaseUrl() ?>")
                            .attr('data-text', "<?php echo $block->getShareText() ?>")
                        <?php if ($image = $block->getCustomLogo('skype')): ?>
                            .append($("<img>").attr("class", "jssocials-share-logo").attr('src', "<?= $image ?>"))
                        <?php else: ?>
                            .append($("<i>").attr("class", "fa fa-skype jssocials-share-logo"))
                        <?php endif; ?>
                            .append($("<span>").text('Skype').addClass('jssocials-share-label'))
                            .appendTo($result);
                        return $result;
                    }
                }
                <?php endif; ?>
            ],
            shareIn: "popup",
            text: "<?php echo $block->getShareText() ?>",
            url: "<?php echo $block->getBaseUrl() ?>"
        });
    });
});
```
Check if share buttons are enabled:
```php
$isEnabled = $block->isModuleEnabled();
```
Get enabled share buttons inside template:  
```php  
$enabledSocials = $block->getEnabledSocials();
```
Get share text:
```php
$shareText = $block->getShareText();
```  
Get custom share button icon:
```php
$share = $enabledSocials['jsSocials'][0];
$shareIcon = $block->getCustomLogo($share);
```
![Example of share buttons with custom logo](social_share.gif)